summaryrefslogtreecommitdiffstats
path: root/chalk/ui/kis_dlg_adjustment_layer.h
diff options
context:
space:
mode:
Diffstat (limited to 'chalk/ui/kis_dlg_adjustment_layer.h')
-rw-r--r--chalk/ui/kis_dlg_adjustment_layer.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/chalk/ui/kis_dlg_adjustment_layer.h b/chalk/ui/kis_dlg_adjustment_layer.h
index 4e20b8fd..dd799260 100644
--- a/chalk/ui/kis_dlg_adjustment_layer.h
+++ b/chalk/ui/kis_dlg_adjustment_layer.h
@@ -50,13 +50,13 @@ public:
* @param caption the caption for the dialog -- create or properties
* @param create if true, set the dialog up for creating a new adj. layer, if false, edit the
* propeties of the current adj. layer
* @param tqparent the widget tqparent of this dialog
* @param name the TQObject name, if any
*/
KisDlgAdjustmentLayer(KisImage * img,
const TQString & layerName,
const TQString & caption,
- TQWidget *tqparent = 0,
+ TQWidget *parent = 0,
const char *name = 0);
KisFilterConfiguration * filterConfiguration() const;
@@ -50,13 +50,13 @@ public:
* @param create if true, set the dialog up for creating a new adj. layer, if false, edit the
* propeties of the current adj. layer
- * @param tqparent the widget tqparent of this dialog
+ * @param parent the widget parent of this dialog
* @param name the TQObject name, if any
*/